@@ -1,24 +1,27 @@
 from __future__ import annotations
 
 import operator
+from io import BytesIO
 from typing import TYPE_CHECKING, Any, Literal, cast
 
 import ibis
 import ibis.expr.types as ir
 
 from narwhals._ibis.utils import evaluate_exprs, native_to_narwhals_dtype
+from narwhals._sql.dataframe import SQLLazyFrame
 from narwhals._utils import (
     Implementation,
     ValidateBackendVersion,
     Version,
     not_implemented,
     parse_columns_to_drop,
+    zip_strict,
 )
 from narwhals.exceptions import ColumnNotFoundError, InvalidOperationError
-from narwhals.typing import CompliantLazyFrame
 
 if TYPE_CHECKING:
     from collections.abc import Iterable, Iterator, Mapping, Sequence
+    from pathlib import Path
     from types import ModuleType
 
     import pandas as pd
@@ -31,6 +34,7 @@ if TYPE_CHECKING:
     from narwhals._ibis.group_by import IbisGroupBy
     from narwhals._ibis.namespace import IbisNamespace
     from narwhals._ibis.series import IbisInterchangeSeries
+    from narwhals._typing import _EagerAllowedImpl
     from narwhals._utils import _LimitedContext
     from narwhals.dataframe import LazyFrame
     from narwhals.dtypes import DType
@@ -41,9 +45,7 @@ if TYPE_CHECKING:
 
 
 class IbisLazyFrame(
-    CompliantLazyFrame[
-        "IbisExpr", "ir.Table", "LazyFrame[ir.Table] | DataFrameV1[ir.Table]"
-    ],
+    SQLLazyFrame["IbisExpr", "ir.Table", "LazyFrame[ir.Table] | DataFrameV1[ir.Table]"],
     ValidateBackendVersion,
 ):
     _implementation = Implementation.IBIS
@@ -101,7 +103,7 @@ class IbisLazyFrame(
             yield self.native[name]
 
     def collect(
-        self, backend: ModuleType | Implementation | str | None, **kwargs: Any
+        self, backend: _EagerAllowedImpl | None, **kwargs: Any
     ) -> CompliantDataFrameAny:
         if backend is None or backend is Implementation.PYARROW:
             from narwhals._arrow.dataframe import ArrowDataFrame
@@ -163,7 +165,7 @@ class IbisLazyFrame(
         selection = (col for col in self.columns if col not in columns_to_drop)
         return self._with_native(self.native.select(*selection))
 
-    def lazy(self, *, backend: Implementation | None = None) -> Self:
+    def lazy(self, backend: None = None, **_: None) -> Self:
         # The `backend`` argument has no effect but we keep it here for
         # backwards compatibility because in `narwhals.stable.v1`
         # function `.from_native()` will return a DataFrame for Ibis.
@@ -307,7 +309,7 @@ class IbisLazyFrame(
             return left_on
         return [
             cast("ir.BooleanColumn", (self.native[left] == other.native[right]))
-            for left, right in zip(left_on, right_on)
+            for left, right in zip_strict(left_on, right_on)
         ]
 
     def collect_schema(self) -> dict[str, DType]:
@@ -334,17 +336,17 @@ class IbisLazyFrame(
         return self._with_native(self.native.distinct(on=subset))
 
     def sort(self, *by: str, descending: bool | Sequence[bool], nulls_last: bool) -> Self:
-        if isinstance(descending, bool):
-            descending = [descending for _ in range(len(by))]
+        from narwhals._ibis.expr import IbisExpr
 
-        sort_cols = []
+        cols = IbisExpr._sort(*by, descending=descending, nulls_last=nulls_last)
+        return self._with_native(self.native.order_by(*cols))
 
-        for i in range(len(by)):
-            direction_fn = ibis.desc if descending[i] else ibis.asc
-            col = direction_fn(by[i], nulls_first=not nulls_last)
-            sort_cols.append(cast("ir.Column", col))
+    def top_k(self, k: int, *, by: Iterable[str], reverse: bool | Sequence[bool]) -> Self:
+        from narwhals._ibis.expr import IbisExpr
 
-        return self._with_native(self.native.order_by(*sort_cols))
+        desc = not reverse if isinstance(reverse, bool) else [not el for el in reverse]
+        cols = IbisExpr._sort(*by, descending=desc, nulls_last=True)
+        return self._with_native(self.native.order_by(*cols).head(k))
 
     def drop_nulls(self, subset: Sequence[str] | None) -> Self:
         subset_ = subset if subset is not None else self.columns
@@ -401,9 +403,18 @@ class IbisLazyFrame(
         ]
         return self._with_native(self.native.select(*to_select))
 
+    def sink_parquet(self, file: str | Path | BytesIO) -> None:
+        if isinstance(file, BytesIO):  # pragma: no cover
+            msg = "Writing to BytesIO is not supported for Ibis backend."
+            raise NotImplementedError(msg)
+        self.native.to_parquet(file)
+
     gather_every = not_implemented.deprecated(
         "`LazyFrame.gather_every` is deprecated and will be removed in a future version."
     )
     tail = not_implemented.deprecated(
         "`LazyFrame.tail` is deprecated and will be removed in a future version."
     )
+
+    # Intentionally not implemented, as Ibis does its own expression rewriting.
+    _evaluate_window_expr = not_implemented()
