@@ -1,7 +1,6 @@
 from __future__ import annotations
 
 import operator
-from functools import partial
 from typing import TYPE_CHECKING, Any, Callable, Literal, TypeVar, cast
 
 import ibis
@@ -10,9 +9,19 @@ from narwhals._ibis.expr_dt import IbisExprDateTimeNamespace
 from narwhals._ibis.expr_list import IbisExprListNamespace
 from narwhals._ibis.expr_str import IbisExprStringNamespace
 from narwhals._ibis.expr_struct import IbisExprStructNamespace
-from narwhals._ibis.utils import is_floating, lit, narwhals_to_native_dtype
+from narwhals._ibis.utils import (
+    IntoColumn,
+    asc_nulls_first,
+    asc_nulls_last,
+    desc_nulls_first,
+    desc_nulls_last,
+    extend_bool,
+    is_floating,
+    lit,
+    narwhals_to_native_dtype,
+)
 from narwhals._sql.expr import SQLExpr
-from narwhals._utils import Implementation, Version, not_implemented
+from narwhals._utils import Implementation, Version, not_implemented, zip_strict
 
 if TYPE_CHECKING:
     from collections.abc import Iterator, Sequence
@@ -79,7 +88,7 @@ class IbisExpr(SQLExpr["IbisLazyFrame", "ir.Value"]):
         self,
         expr: ir.Value,
         partition_by: Sequence[str | ir.Value] = (),
-        order_by: Sequence[str | ir.Column] = (),
+        order_by: Sequence[IntoColumn] = (),
         rows_start: int | None = None,
         rows_end: int | None = None,
         *,
@@ -94,15 +103,15 @@ class IbisExpr(SQLExpr["IbisLazyFrame", "ir.Value"]):
             rows_between = {"preceding": -rows_start}
         else:
             rows_between = {}
+        desc = descending or False
+        last = nulls_last or False
         window = ibis.window(
             group_by=partition_by,
-            order_by=self._sort(*order_by, descending=descending, nulls_last=nulls_last),
+            order_by=self._sort(*order_by, descending=desc, nulls_last=last),
             **rows_between,
         )
         return expr.over(window)
 
-    def __narwhals_expr__(self) -> None: ...
-
     def __narwhals_namespace__(self) -> IbisNamespace:  # pragma: no cover
         from narwhals._ibis.namespace import IbisNamespace
 
@@ -112,24 +121,23 @@ class IbisExpr(SQLExpr["IbisLazyFrame", "ir.Value"]):
         # Ibis does its own broadcasting.
         return self
 
+    @staticmethod
     def _sort(
-        self,
-        *cols: ir.Column | str,
-        descending: Sequence[bool] | None = None,
-        nulls_last: Sequence[bool] | None = None,
+        *cols: IntoColumn,
+        descending: Sequence[bool] | bool = False,
+        nulls_last: Sequence[bool] | bool = False,
     ) -> Iterator[ir.Column]:
-        descending = descending or [False] * len(cols)
-        nulls_last = nulls_last or [False] * len(cols)
+        n = len(cols)
+        descending = extend_bool(descending, n)
+        nulls_last = extend_bool(nulls_last, n)
         mapping = {
-            (False, False): partial(ibis.asc, nulls_first=True),
-            (False, True): partial(ibis.asc, nulls_first=False),
-            (True, False): partial(ibis.desc, nulls_first=True),
-            (True, True): partial(ibis.desc, nulls_first=False),
+            (False, False): asc_nulls_first,
+            (False, True): asc_nulls_last,
+            (True, False): desc_nulls_first,
+            (True, True): desc_nulls_last,
         }
-        yield from (
-            cast("ir.Column", mapping[(_desc, _nulls_last)](col))
-            for col, _desc, _nulls_last in zip(cols, descending, nulls_last)
-        )
+        for col, _desc, _nulls_last in zip_strict(cols, descending, nulls_last):
+            yield mapping[(_desc, _nulls_last)](col)
 
     @classmethod
     def from_column_names(
@@ -178,10 +186,10 @@ class IbisExpr(SQLExpr["IbisLazyFrame", "ir.Value"]):
         return self._with_callable(invert)
 
     def all(self) -> Self:
-        return self._with_callable(lambda expr: expr.all().fill_null(lit(True)))  # noqa: FBT003
+        return self._with_callable(lambda expr: expr.all().fill_null(lit(True)))
 
     def any(self) -> Self:
-        return self._with_callable(lambda expr: expr.any().fill_null(lit(False)))  # noqa: FBT003
+        return self._with_callable(lambda expr: expr.any().fill_null(lit(False)))
 
     def quantile(
         self, quantile: float, interpolation: RollingInterpolationMethod
@@ -219,7 +227,7 @@ class IbisExpr(SQLExpr["IbisLazyFrame", "ir.Value"]):
             version=self._version,
         )
 
-    def std(self, ddof: int) -> Self:
+    def std(self, *, ddof: int) -> Self:
         def _std(expr: ir.NumericColumn, ddof: int) -> ir.Value:
             if ddof == 0:
                 return expr.std(how="pop")
@@ -227,12 +235,12 @@ class IbisExpr(SQLExpr["IbisLazyFrame", "ir.Value"]):
                 return expr.std(how="sample")
             n_samples = expr.count()
             std_pop = expr.std(how="pop")
-            ddof_lit = cast("ir.IntegerScalar", ibis.literal(ddof))
+            ddof_lit = lit(ddof)
             return std_pop * n_samples.sqrt() / (n_samples - ddof_lit).sqrt()
 
         return self._with_callable(lambda expr: _std(expr, ddof))
 
-    def var(self, ddof: int) -> Self:
+    def var(self, *, ddof: int) -> Self:
         def _var(expr: ir.NumericColumn, ddof: int) -> ir.Value:
             if ddof == 0:
                 return expr.var(how="pop")
@@ -240,7 +248,7 @@ class IbisExpr(SQLExpr["IbisLazyFrame", "ir.Value"]):
                 return expr.var(how="sample")
             n_samples = expr.count()
             var_pop = expr.var(how="pop")
-            ddof_lit = cast("ir.IntegerScalar", ibis.literal(ddof))
+            ddof_lit = lit(ddof)
             return var_pop * n_samples / (n_samples - ddof_lit)
 
         return self._with_callable(lambda expr: _var(expr, ddof))
@@ -290,35 +298,33 @@ class IbisExpr(SQLExpr["IbisLazyFrame", "ir.Value"]):
         )
 
     def rank(self, method: RankMethod, *, descending: bool) -> Self:
-        def _rank(expr: ir.Column) -> ir.Column:
-            order_by = next(self._sort(expr, descending=[descending], nulls_last=[True]))
+        def _rank(expr: ir.Column) -> ir.Value:
+            order_by = next(self._sort(expr, descending=descending, nulls_last=True))
             window = ibis.window(order_by=order_by)
 
             if method == "dense":
                 rank_ = order_by.dense_rank()
             elif method == "ordinal":
-                rank_ = cast("ir.IntegerColumn", ibis.row_number().over(window))
+                rank_ = ibis.row_number().over(window)
             else:
                 rank_ = order_by.rank()
 
             # Ibis uses 0-based ranking. Add 1 to match polars 1-based rank.
-            rank_ = rank_ + cast("ir.IntegerValue", lit(1))
+            rank_ = rank_ + lit(1)
 
             # For "max" and "average", adjust using the count of rows in the partition.
             if method == "max":
                 # Define a window partitioned by expr (i.e. each distinct value)
                 partition = ibis.window(group_by=[expr])
-                cnt = cast("ir.IntegerValue", expr.count().over(partition))
-                rank_ = rank_ + cnt - cast("ir.IntegerValue", lit(1))
+                cnt = expr.count().over(partition)
+                rank_ = rank_ + cnt - lit(1)
             elif method == "average":
                 partition = ibis.window(group_by=[expr])
-                cnt = cast("ir.IntegerValue", expr.count().over(partition))
-                avg = cast(
-                    "ir.NumericValue", (cnt - cast("ir.IntegerScalar", lit(1))) / lit(2.0)
-                )
+                cnt = expr.count().over(partition)
+                avg = cast("ir.NumericValue", (cnt - lit(1)) / lit(2.0))
                 rank_ = rank_ + avg
 
-            return cast("ir.Column", ibis.cases((expr.notnull(), rank_)))
+            return ibis.cases((expr.notnull(), rank_))
 
         return self._with_callable(_rank)
 
