@@ -18,9 +18,6 @@ class ExprListNamespace(Generic[ExprT]):
 
         Null values count towards the total.
 
-        Returns:
-            A new expression.
-
         Examples:
             >>> import polars as pl
             >>> import narwhals as nw
@@ -52,9 +49,6 @@ class ExprListNamespace(Generic[ExprT]):
 
         Null values are included in the result. The order of unique values is not guaranteed.
 
-        Returns:
-            A new expression.
-
         Examples:
             >>> import polars as pl
             >>> import narwhals as nw
@@ -87,9 +81,6 @@ class ExprListNamespace(Generic[ExprT]):
         Arguments:
             item: Item that will be checked for membership.
 
-        Returns:
-            A new expression.
-
         Examples:
             >>> import polars as pl
             >>> import narwhals as nw
@@ -114,3 +105,46 @@ class ExprListNamespace(Generic[ExprT]):
         return self._expr._with_elementwise(
             lambda plx: self._expr._to_compliant_expr(plx).list.contains(item)
         )
+
+    def get(self, index: int) -> ExprT:
+        """Return the value by index in each list.
+
+        Negative indices are not accepted.
+
+        Returns:
+            A new expression.
+
+        Examples:
+            >>> import polars as pl
+            >>> import narwhals as nw
+            >>> df_native = pl.DataFrame({"a": [[1, 2], [3, 4, None], [None, 5]]})
+            >>> df = nw.from_native(df_native)
+            >>> df.with_columns(a_first=nw.col("a").list.get(0))
+            ┌──────────────────────────┐
+            |    Narwhals DataFrame    |
+            |--------------------------|
+            |shape: (3, 2)             |
+            |┌──────────────┬─────────┐|
+            |│ a            ┆ a_first │|
+            |│ ---          ┆ ---     │|
+            |│ list[i64]    ┆ i64     │|
+            |╞══════════════╪═════════╡|
+            |│ [1, 2]       ┆ 1       │|
+            |│ [3, 4, null] ┆ 3       │|
+            |│ [null, 5]    ┆ null    │|
+            |└──────────────┴─────────┘|
+            └──────────────────────────┘
+        """
+        if not isinstance(index, int):
+            msg = (
+                f"Index must be of type 'int'. Got type '{type(index).__name__}' instead."
+            )
+            raise TypeError(msg)
+
+        if index < 0:
+            msg = f"Index {index} is out of bounds: should be greater than or equal to 0."
+            raise ValueError(msg)
+
+        return self._expr._with_elementwise(
+            lambda plx: self._expr._to_compliant_expr(plx).list.get(index)
+        )
