@@ -445,18 +445,12 @@ def test_series_from_numpy(
         (nw_v2.Int64, [5, 2, 0, 1]),
         (nw_v2.String, ("a", "b", "c")),
         (nw_v2.Float64, [5.0, 2.0, 0.0, 1.0]),
-        (
-            nw_v2.Datetime("ms"),
-            deque([datetime(2005, 1, 1, 10), datetime(2002, 1, 1, 10, 43)]),
-        ),
+        (nw_v2.Datetime, deque([datetime(2005, 1, 1, 10), datetime(2002, 1, 1, 10, 43)])),
     ],
     ids=str,
 )
 def test_series_from_iterable(
-    eager_backend: EagerAllowed,
-    dtype: IntoDType | None,
-    expected: Sequence[Any],
-    request: pytest.FixtureRequest,
+    eager_backend: EagerAllowed, dtype: IntoDType | None, expected: Sequence[Any]
 ) -> None:
     data = expected
     name = "abc"
@@ -464,14 +458,6 @@ def test_series_from_iterable(
     assert result._version is Version.V2
     assert isinstance(result, nw_v2.Series)
     if dtype:
-        request.applymarker(
-            pytest.mark.xfail(
-                result.implementation.is_pandas_like()
-                and dtype.is_temporal()
-                and PANDAS_VERSION < (2,),
-                reason='Pandas does not support "ms" or "us" time units before version 2.0',
-            )
-        )
         assert result.dtype == dtype
     assert_equal_series(result, expected, name)
 
